/*
Copyright (c) 2006, Dennis M. Sosnoski
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
 * Neither the name of JiBX nor the names of its contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.jibx.typeinfo;

import java.lang.reflect.Modifier;

/**
 * Descriptor for array class. This is just a wrapper around the descriptor
 * for the item type, with the same field list used for all arrays.
 */
public class ArrayClassDescriptor extends TypeDescription
{
    /** Field list for all arrays. */
    private static final FieldDescription[] ARRAY_FIELDS =
        new FieldDescription[] { new FieldDescription("int", Modifier.PUBLIC,
        PrimitiveTypeDescription.INT_TYPE)
    };
    
    /** Type of items in array. */
    private final TypeDescription m_itemType;
    
    /**
     * Constructor.
     * 
     * @param iname internal name
     * @param itype item tpe
     */
    public ArrayClassDescriptor(String iname, TypeDescription itype) {
        super(iname);
        m_itemType = itype;
    }
    
    //
    // Base class overrides
    
    /* (non-Javadoc)
     * @see org.jibx.typeinfo.TypeDescription#isArray()
     */
    public boolean isArray() {
        return true;
    }
    
    /* (non-Javadoc)
     * @see org.jibx.typeinfo.TypeDescription#getArrayItemType()
     */
    public TypeDescription getArrayItemType() {
        return m_itemType;
    }
    
    /* (non-Javadoc)
     * @see org.jibx.typeinfo.TypeDescription#getFields()
     */
    public FieldDescription[] getFields() {
        return ARRAY_FIELDS;
    }
    
    /* (non-Javadoc)
     * @see org.jibx.typeinfo.TypeDescription#toString()
     */
    public String toString() {
        return m_itemType + "[]";
    }
}